@@ -10,10 +10,12 @@ import (
 	"time"
 
 	configv1 "github.com/openshift/api/config/v1"
-	olm "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
-	"github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
-	"github.com/operator-framework/operator-marketplace/pkg/apis/operators/v2"
+	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
+	olm "github.com/operator-framework/operator-marketplace/pkg/apis/olm/v1alpha1"
+	v1 "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
+	v2 "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v2"
 	"github.com/operator-framework/operator-marketplace/pkg/builders"
+	"github.com/operator-framework/operator-marketplace/pkg/defaults"
 	"github.com/operator-framework/operator-sdk/pkg/test"
 	apps "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -75,7 +77,7 @@ var (
 
 	// DefaultSources is the in-memory copy of the default OperatorSource definitions
 	// from the defaults directory.
-	DefaultSources []*v1.OperatorSource
+	DefaultSources []*olm.CatalogSource
 )
 
 // WaitForResult polls the cluster for a particular resource name and namespace.
@@ -139,6 +141,24 @@ func WaitForOpSrcExpectedPhaseAndMessage(client test.FrameworkClient, opSrcName
 	return resultOperatorSource, nil
 }
 
+// WaitForExpectedSpec compares two CatalogSources and return true if their Specs are equal.
+func WaitForExpectedSpec(client test.FrameworkClient, name string, namespace string, expected *olm.CatalogSource) error {
+	err := wait.Poll(RetryInterval, Timeout, func() (bool, error) {
+		actual := &olm.CatalogSource{}
+		if err := client.Get(context.TODO(), types.NamespacedName{Name: name, Namespace: namespace}, actual); err != nil {
+			return false, err
+		}
+		if defaults.AreCatsrcSpecsEqual(&expected.Spec, &actual.Spec) {
+			return true, nil
+		}
+		return false, nil
+	})
+	if err != nil {
+		return err
+	}
+	return nil
+}
+
 // WaitForNotFound polls the cluster for a particular resource name and namespace
 // If the request fails because the runtime object is found it retries until the specified timeout
 // If the request returns a IsNotFound error the method will return true
@@ -337,6 +357,19 @@ func WaitForOpsrcMarkedForDeletionWithFinalizer(client test.FrameworkClient, nam
 	})
 }
 
+// WaitForCatsrcMarkedForDeletion waits until a CatalogSource is either deleted or is marked for deletion
+func WaitForCatsrcMarkedForDeletion(client test.FrameworkClient, name, namespace string) error {
+	resultCatalogSource := &olm.CatalogSource{}
+	namespacedName := types.NamespacedName{Name: name, Namespace: namespace}
+	return wait.PollImmediate(RetryInterval, Timeout, func() (done bool, err error) {
+		err = client.Get(context.TODO(), namespacedName, resultCatalogSource)
+		if resultCatalogSource.DeletionTimestamp != nil || errors.IsNotFound(err) {
+			return true, nil
+		}
+		return false, err
+	})
+}
+
 // WaitForDeploymentScaled waits Timeout amount of time for the given deployment to be updated
 // with the specified number of replicas.
 func WaitForDeploymentScaled(client test.FrameworkClient, name, namespace string, replicas int32) error {
@@ -406,7 +439,7 @@ func ScaleMarketplace(client test.FrameworkClient, namespace string, scale int32
 
 // CreateSubscriptionDefinition returns a newly built Subscription with the labels
 // `csc-owner-name` and `csc-owner-namespace` based on the catalogsourceconfig and the expected name
-func CreateSubscriptionDefinition(name, namespace, cscName string, isCreatedByUI bool) *olm.Subscription {
+func CreateSubscriptionDefinition(name, namespace, cscName string, isCreatedByUI bool) *v1alpha1.Subscription {
 	labels := make(map[string]string)
 	specSource := fmt.Sprintf("%s-%s", cscName, namespace)
 
@@ -415,18 +448,18 @@ func CreateSubscriptionDefinition(name, namespace, cscName string, isCreatedByUI
 		labels[builders.CscOwnerNamespaceLabel] = namespace
 	}
 
-	return &olm.Subscription{
+	return &v1alpha1.Subscription{
 		TypeMeta: metav1.TypeMeta{
 			APIVersion: fmt.Sprintf("%s/%s",
-				olm.SchemeGroupVersion.Group, olm.SchemeGroupVersion.Version),
-			Kind: olm.SubscriptionKind,
+				v1alpha1.SchemeGroupVersion.Group, v1alpha1.SchemeGroupVersion.Version),
+			Kind: v1alpha1.SubscriptionKind,
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      name,
 			Namespace: namespace,
 			Labels:    labels,
 		},
-		Spec: &olm.SubscriptionSpec{
+		Spec: &v1alpha1.SubscriptionSpec{
 			CatalogSource:          specSource,
 			CatalogSourceNamespace: namespace,
 			Channel:                "alpha",
@@ -437,7 +470,7 @@ func CreateSubscriptionDefinition(name, namespace, cscName string, isCreatedByUI
 // CheckSubscriptionNotUpdated checks that a user created subscription
 // was not updated during migration.
 func CheckSubscriptionNotUpdated(client test.FrameworkClient, namespace, subscriptionName, installedCscName string) error {
-	subscription := &olm.Subscription{}
+	subscription := &v1alpha1.Subscription{}
 	specSource := fmt.Sprintf("%s-%s", installedCscName, namespace)
 	err := client.Get(context.TODO(), types.NamespacedName{Name: subscriptionName, Namespace: namespace}, subscription)
 	if err != nil {
@@ -497,9 +530,9 @@ func EnsureConfigAPIIsAvailable() (bool, error) {
 	return *isConfigAPIPresent, err
 }
 
-// InitOpSrcDefinition reads a default OperatorSource definition from the default directory
+// InitCatSrcDefinition reads a default CatalogSource definition from the default directory
 // and initializes DefaultSources
-func InitOpSrcDefinition() error {
+func InitCatSrcDefinition() error {
 	if DefaultSources != nil {
 		return nil
 	}
@@ -509,7 +542,7 @@ func InitOpSrcDefinition() error {
 		return err
 	}
 
-	DefaultSources = make([]*v1.OperatorSource, len(fileInfos))
+	DefaultSources = make([]*olm.CatalogSource, len(fileInfos))
 
 	for i, fileInfo := range fileInfos {
 		fileName := fileInfo.Name()
@@ -519,7 +552,7 @@ func InitOpSrcDefinition() error {
 			return err
 		}
 
-		DefaultSources[i] = &v1.OperatorSource{}
+		DefaultSources[i] = &olm.CatalogSource{}
 		decoder := yaml.NewYAMLOrJSONDecoder(file, 1024)
 		err = decoder.Decode(DefaultSources[i])
 		if err != nil {
